@@ -1,6 +1,6 @@
 ##############################################################################
 # JSON::Any
-# v1.06
+# v1.07
 # Copyright (c) 2007 Chris Thompson
 ##############################################################################
 
@@ -10,15 +10,29 @@ use warnings;
 use strict;
 use Carp;
 
-my ( %conf, $handler, $encoder, $decoder );
+=head1 NAME
 
+JSON::Any - Wrapper Class for the various JSON classes.
+
+=head1 VERSION
+
+Version 1.07
+
+=cut
+
+our $VERSION = '1.07';
+
+my ( %conf, $handler, $encoder, $decoder );
+use constant HANDLER => 0;
+use constant ENCODER => 1;
+use constant DECODER => 2;
 BEGIN {
     %conf = (
         json => {
             encoder       => 'objToJson',
             decoder       => 'jsonToObj',
             create_object => sub {
-                my ($self) = @_;
+                my ($self, $conf) = @_;
                 my @params = qw(
                   autoconv
                   skipinvalid
@@ -31,7 +45,9 @@ BEGIN {
                   selfconvert
                   singlequote
                 );
-                return $handler->new( map { $_ => $self->{$_} } @params );
+                $self->[ENCODER] = 'objToJson';
+                $self->[DECODER] = 'jsonToObj',
+                $self->[HANDLER] = $handler->new( map { $_ => $conf->{$_} } @params );
             },
         },
 
@@ -39,9 +55,11 @@ BEGIN {
             encoder       => 'to_json',
             decoder       => 'from_json',
             create_object => sub {
-                my ($self) = @_;
+                my ($self, $conf) = @_;
                 my @params = qw(bare_keys);
-                return $handler->new( { map { $_ => $self->{$_} } @params } );
+                $self->[ENCODER] = 'to_json';
+                $self->[DECODER] = 'from_json',                
+                $self->[HANDLER] = $handler->new( { map { $_ => $conf->{$_} } @params } );
             },
         },
 
@@ -49,7 +67,7 @@ BEGIN {
             encoder       => 'to_json',
             decoder       => 'from_json',
             create_object => sub {
-                my ($self) = @_;
+                my ($self, $conf) = @_;
 
                 my @params = qw(
                   ascii
@@ -66,12 +84,12 @@ BEGIN {
 
                 my $obj = $handler->new;
                 for my $mutator (@params) {
-                    next unless exists $self->{$mutator};
-                    $obj = $obj->$mutator( $self->{$mutator} );
+                    next unless exists $conf->{$mutator};
+                    $obj = $obj->$mutator( $conf->{$mutator} );
                 }
-                $encoder = 'encode';
-                $decoder = 'decode';
-                return $obj;
+                $self->[ENCODER] = 'encode';
+                $self->[DECODER] = 'decode',                
+                $self->[HANDLER] = $obj;
             },
         },
         json_syck => {
@@ -90,7 +108,8 @@ sub import {
 
     ( $handler, $encoder, $decoder ) = ();
 
-    if ( $ENV{JSON_ANY_ORDER} && !scalar @order ) {
+    if ( $ENV{JSON_ANY_ORDER} ) {
+        next if @order;
         @order = split /\s/, $ENV{JSON_ANY_ORDER};
     }
     @order = qw(XS JSON DWIW Syck) unless @order;
@@ -112,18 +131,6 @@ sub import {
     croak "Couldn't find a encoder method." unless $encoder;
 }
 
-=head1 NAME
-
-JSON::Any - Wrapper Class for the various JSON classes.
-
-=head1 VERSION
-
-Version 1.06
-
-=cut
-
-our $VERSION = '1.06';
-
 =head1 SYNOPSIS
 
 This module will provide a coherent API to bring together the various JSON
@@ -203,7 +210,7 @@ sub new {
             push @config, map { split /=/, $_ } split /,\s*/,
               $ENV{JSON_ANY_CONFIG};
         }
-        $self->[0] = $creator->( {@config} );
+        $creator->( $self, {@config} );
     }
     return $self;
 }
@@ -238,7 +245,7 @@ class methods.
 sub handler {
     my $self = shift;
     if ( ref $self ) {
-        return $self->[0];
+        return $self->[HANDLER];
     }
     return $handler;
 }
@@ -258,10 +265,10 @@ sub objToJson {
     my $self = shift;
     my $obj  = shift;
     if ( ref $self ) {
-        croak "No $handler Object created!" unless exists $self->[0];
-        my $method = $self->[0]->can($encoder);
+        croak "No $handler Object created!" unless exists $self->[HANDLER];
+        my $method = $self->[HANDLER]->can($self->[ENCODER]);
         croak "$handler can't execute $encoder" unless $method;
-        return $self->[0]->$method($obj);
+        return $self->[HANDLER]->$method($obj);
     }
     return $handler->can($encoder)->($obj);
 }
@@ -303,10 +310,10 @@ sub jsonToObj {
     my $self = shift;
     my $obj  = shift;
     if ( ref $self ) {
-        croak "No $handler Object created!" unless exists $self->[0];
-        my $method = $self->[0]->can($decoder);
+        croak "No $handler Object created!" unless exists $self->[HANDLER];
+        my $method = $self->[HANDLER]->can($self->[ENCODER]);
         croak "$handler can't execute $encoder" unless $method;
-        return $self->[0]->$method($obj);
+        return $self->[HANDLER]->$method($obj);
     }
     $handler->can($decoder)->($obj);
 }
